'************************************************************************************* 
' 
' Peter Mather
' 
' 1.2 
' 2015-18-1 
'  
' Graphics library with drivers for ILI9341 TFT 2.8" and TFT 2.4" displays
' NB this display controller reports an ID of 9341 or 9340
'
' drawing primitives assume a graphics display where top left is point 0, 0
'
' set screen orientation: sub I9341.setrot(x) ;I9341_normal=normal, I9341_inverse=invert, I9341_rt_right=rotate right, I9341_rt_left=rotate left
' draw circle: sub I9341.dcirc(x0, y0, r, colour) ;x, y coordinates of centre, radius, colour
' draw filled circle: sub I9341.fcirc(x0, y0, r, colour) ;x, y coordinates of centre, radius, colour
' draw triangle:  sub I9341.dtri(x0, y0, x1, y1, 	x2, y2, colour) ;three coordinate pairs, colour
' draw filled triangle sub I9341.ftri (x0, y0, x1, y1, x2, y2, colour) ;three coordinate pairs, colour
' print string: sub I9341.pstring(xx0, yy0, text$, sz, orientation, forecolour, backcolour) ;x, y coordinates of top left of first character, text string, size, character orientation,  foreground colour,  background colour
' print 8x5 bitmap: sub I9341.pbitmap(xx0, yy0, char, sz, orientation, forecolour, backcolour) ;x, y coordinates of top left of first character, bitmap, size, character orientation,  foreground colour,  background colour
' draw line: sub I9341.dline(xx0, yy0, xx1, yy1, colour) ;x, y of start line, x, y of end line, colour
' draw rectangle: sub I9341.drect(x, y, w, h, colour) ;x, y coordinate of top left, width, height, colour
' draw filled rectangle: sub I9341.frect(x, y, w, h, colour) ;x, y coordinate of top left, width, height, colour
' draw rounded rectangle: sub I9341.drndrect(x, y, w, h, r, colour) ;x, y coordinates of top left, width, height, radius of corner, colour
' draw filled rounded rectangle: sub I9341.frndrect(x, y, w, h, r, colour) ;x, y coordinates of top left, width, height, radius of corner, colour
'
option explicit
option default NONE
cpu 48
  I9341_initialise
do
  I9341_test
loop
end
'
' ILI9341 specific routines
'
sub I9341.initdisplay
'Global "Constants"
  dim integer I9341_CS=2 'a0
  dim integer I9341_RS=3 'a1
  dim integer I9341_WR=9 'a2
  dim integer I9341_RD=10 'a3
  dim integer I9341_RESET= 14 'b5
  dim integer I9341_D0=4' b0
  dim integer I9341_D1=5' b1
  dim integer I9341_D2=6' b2
  dim integer I9341_D3=7' b3
  dim integer I9341_D4=23' b12
  dim integer I9341_D5=24' b13
  dim integer I9341_D6=25' b14
  dim integer I9341_D7=26' b15
  dim integer BLACK = &H0000 ' Color definitions: 16 bit (RGB565) colour palette so these are just examples
  dim integer BLUE  = &H001F
  dim integer RED   = &HF800
  dim integer GREEN = &H07E0
  dim integer CYAN  = &H07FF
  dim integer MAGENTA=&HF81F
  dim integer YELLOW= &HFFE0 
  dim integer WHITE = &HFFFF
  dim integer I9341.pix=0
  dim integer I9341.ffr=1
  dim integer I9341.filltri=2
  dim integer I9341.drawline=3
  dim integer I9341.writecommand=4
  dim integer I9341.writedata=5
  dim integer I9341.fpstring=7
  dim integer I9341.fcirch=8
  dim integer I9341.dcirch=9
  dim integer I9341.writebyte=10
  dim integer I9341.writedata32=11
  dim integer I9341_normal=0
  dim integer I9341_inverse=1
  dim integer I9341_rt_right=2
  dim integer I9341_rt_left=3
  Const ILI9341_SOFTRESET          =&H01
  Const ILI9341_SLEEPIN            =&H10
  Const ILI9341_SLEEPOUT           =&H11
  Const ILI9341_NORMALDISP         =&H13
  Const ILI9341_INVERTOFF          =&H20
  Const ILI9341_INVERTON           =&H21
  Const ILI9341_GAMMASET           =&H26
  Const ILI9341_DISPLAYOFF         =&H28
  Const ILI9341_DISPLAYON          =&H29
  Const ILI9341_COLADDRSET         =&H2A
  Const ILI9341_PAGEADDRSET        =&H2B
  Const ILI9341_MEMORYWRITE        =&H2C
  Const ILI9341_PIXELFORMAT        =&H3A
  Const ILI9341_FRAMECONTROL       =&HB1
  Const ILI9341_DISPLAYFUNC        =&HB6
  Const ILI9341_ENTRYMODE          =&HB7
  Const ILI9341_POWERCONTROL1      =&HC0
  Const ILI9341_POWERCONTROL2      =&HC1
  Const ILI9341_VCOMCONTROL1      =&HC5
  Const ILI9341_VCOMCONTROL2      =&HC7
  DIM integer ILI9341_MEMCONTROL      =&H36
  Const ILI9341_MADCTL  =&H36
  DIM integer  ILI9341_MADCTL_MY  =&H80
  DIM integer  ILI9341_MADCTL_MX  =&H40
  DIM integer  ILI9341_MADCTL_MV  =&H20
  DIM integer  ILI9341_MADCTL_ML  =&H10
  DIM integer  ILI9341_MADCTL_RGB =&H00
  DIM integer  ILI9341_MADCTL_BGR =&H08
  DIM integer  ILI9341_MADCTL_MH  =&H04
  ' Global variables
  dim integer I9341_AddrOfFont,   I9341_params(6) ' Global variables
  DIM integer I9341_wi=0,I9341_ht=1,I9341_rot=2,I9341_nr=3,I9341_X=4,I9341_Y=5,I9341_seed=6
  I9341_AddrOfFont=PEEK(CFunAddr FONT)  
  local integer i
  I9341_params(I9341_wi)=240
  I9341_params(I9341_ht)=320
  pin(I9341_CS)=1
  setpin I9341_CS, DOUT
  pin(I9341_RS)=1
  setpin I9341_RS, DOUT
  pin(I9341_WR)=1
  setpin I9341_WR, DOUT
  pin(I9341_RD)=1
  setpin I9341_RD, DOUT
  pin(I9341_RESET)=1
  setpin I9341_RESET, DOUT'  Reset the display
  I9341.setwrite
  pin(I9341_RESET)=0
  pause 100
  pin(I9341_RESET)=1
  pause 100
  PIN(I9341_CS)=0
  pin(I9341_RS)=0
  port(4, 4, 23, 4)=ILI9341_SOFTRESET
  pulse I9341_WR ,0.01
  pulse I9341_WR ,0.01
  pulse I9341_WR ,0.01
  PIN(I9341_CS)=1
  pause 500
  I9341.wreg(ILI9341_DISPLAYOFF, 0,0)
  I9341.wreg(ILI9341_POWERCONTROL1, &H23,8)
  I9341.wreg(ILI9341_POWERCONTROL2, &H10,8)
  I9341.wreg(ILI9341_VCOMCONTROL1, &H2B2B,16)
  I9341.wreg(ILI9341_VCOMCONTROL2, &HC0,8)
  I9341.wreg(ILI9341_MEMCONTROL, ILI9341_MADCTL_MX OR ILI9341_MADCTL_BGR,8)
  I9341.wreg(ILI9341_PIXELFORMAT, &H55,8)
  I9341.wreg(ILI9341_FRAMECONTROL, &H001B,16)
  I9341.wreg(ILI9341_ENTRYMODE, &H07,8)
  I9341.wreg(ILI9341_SLEEPOUT, 0,8)
  pause 150
  I9341.wreg(ILI9341_DISPLAYON, 0,0)
  pause 500
  I9341.setrot(I9341_normal)
  I9341.wreg(ILI9341_COLADDRSET,239,32)
  I9341.wreg(ILI9341_PAGEADDRSET,319,32)
  I9341.wreg(ILI9341_MEMORYWRITE , 0,8)
end sub
'
sub I9341.wreg(register as integer, databyte as integer, numbits as integer)
  local integer i
  i=I9341draw(I9341.writecommand, register)
  if numbits=16 then i=I9341draw(I9341.writedata, databyte)
  if numbits=32 then i=I9341draw(I9341.writedata32,databyte)
  if numbits=8 then i=I9341draw(I9341.writebyte, databyte)
end sub
'
function I9341.rreg(register as integer) as integer
  local integer i
  i=I9341draw(I9341.writecommand, register)
  pin(I9341_RS)=1
  I9341.rreg= I9341.readdata()
end function
'
sub I9341.fillscreen(scol as integer)
  local integer i=I9341_params(I9341_rot)
  I9341_params(I9341_rot)=0
  local integer j=I9341draw(I9341.ffr,scol, 0,0,I9341_params(I9341_wi),I9341_params(I9341_ht), I9341_params())
  I9341_params(I9341_rot)=i
end sub
'
end sub
'
function  I9341.readdata() as integer
  local integer i 
  I9341.setread
  pin(I9341_cs)=0
  pin(I9341_RD)=0
  i=port(4, 4, 23, 4)
  pin(I9341_RD)=1
  pin(I9341_RD)=0
  i=port(4, 4, 23, 4)
  pin(I9341_RD)=1
  pin(I9341_RD)=0
  i=port(4, 4, 23, 4)<<8
  pin(I9341_RD)=1
  pin(I9341_RD)=0
  i=i+port(4, 4, 23, 4)
  pin(I9341_RD)=1
  I9341.readdata=i
  pin(I9341_CS)=1
  I9341.setwrite
end function
'
sub I9341.setwrite
  setpin I9341_CS, DOUT
  setpin I9341_RS, DOUT
  setpin I9341_WR, DOUT
  setpin I9341_RD, DOUT
  setpin I9341_RESET, DOUT'  Reset the display
  setpin I9341_D0, dout
  setpin I9341_D1, dout
  setpin I9341_D2, dout
  setpin I9341_D3, dout
  setpin I9341_D4, dout
  setpin I9341_D5, dout
  setpin I9341_D6, dout
  setpin I9341_D7, dout
end sub
'
sub I9341.setread
  setpin I9341_D0, din
  setpin I9341_D1, din
  setpin I9341_D2, din
  setpin I9341_D3, din
  setpin I9341_D4, din
  setpin I9341_D5, din
  setpin I9341_D6, din
  setpin I9341_D7, din
end sub
'
' Generic drawing routines
'
sub I9341.dcirc(x0 as integer, y0 as integer, r as integer, colour as integer) 'x, y coordinates of centre, radius
  local integer i=I9341draw(I9341.dcirch, colour,x0,y0,r,31,I9341_params())

end sub
 '
sub I9341.dtri(x0 as integer, y0 as integer, x1 as integer, y1 as integer, x2 as integer, y2 as integer, colour as integer) 'three coordinate pairs
  I9341.dline(x0, y0, x1, y1, colour)
  I9341.dline(x1, y1, x2, y2, colour)
  I9341.dline(x2, y2, x0, y0, colour)
end sub
 '
sub I9341.ftri (x0 as integer, y0 as integer, x1 as integer, y1 as integer, x2 as integer, y2 as integer, colour as integer) 'three coordinate pairs
  local integer i=I9341draw(I9341.filltri, x0,y0,x1,y1,x2,y2,colour,I9341_params())

end sub
'
sub I9341.pstring(xx0 as integer, yy0 as integer, text$, sz as integer, orientation as integer, fontcolour as integer, backgroundcolour as integer) 'x, y coordinates of top left of first character, text string, size, orientation
  local integer i=I9341draw(I9341.fpstring,I9341_AddrOfFont,xx0,yy0,sz,orientation,fontcolour,backgroundcolour,I9341_params(),text$)
end sub
'
sub I9341.pbitmap(xx0 as integer, yy0 as integer, char as integer, sz as integer, orientation as integer, fontcolour as integer, backgroundcolour as integer) 'x, y coordinates of top left of first character, text string, size, orientation
  local integer i=I9341draw(I9341.fpstring,char,xx0,yy0,sz,orientation,fontcolour,backgroundcolour,I9341_params(),"")
end sub
'
sub I9341.dline(xx0 as integer, yy0 as integer, xx1 as integer, yy1 as integer, colour as integer) ' x, y of start line, x, y of end line
   local integer dp=I9341draw(I9341.drawline, colour, xx0, yy0, xx1, yy1,  I9341_params())
end sub
'
sub I9341.drect(x as integer, y as integer, w as integer, h as integer, rcolour as integer) 'x, y coordinate of top left, wi, ht
  local integer a, dp
  dp=I9341draw(I9341.ffr, rcolour, x, y, w, 1,  I9341_params()) 
  a=y+h-1
  dp=I9341draw(I9341.ffr, rcolour, x, a, w, 1,  I9341_params()) 
  dp=I9341draw(I9341.ffr, rcolour, x, y, 1, h,  I9341_params()) 
  a=x+w-1
  dp=I9341draw(I9341.ffr, rcolour, a, y, 1, h,  I9341_params()) 
end sub
'
sub I9341.frect(x as integer, y as integer, w as integer, h as integer, rcolour as integer) 'x, y coordinate of top left, width, height
  local integer dp
  dp=I9341draw(I9341.ffr, rcolour, x, y, w, h,  I9341_params()) 
end sub
'
FUNCTION I9341.Getchar(char as integer) as integer
  local integer i=char<<3
  I9341.Getchar=PEEK(WORD I9341_AddrOfFont+i)+(PEEK(WORD I9341_AddrOfFont+i+4)<<32) 
END FUNCTION
'
sub I9341.fcirc(x0 as integer, y0 as integer, r as integer, ccolour as integer)  'x, y coordinates of centre, radius
  local integer dp
  dp=I9341draw(I9341.ffr, ccolour, x0, y0-r, 1, 2*r+1,  I9341_params())
  dp=I9341draw(I9341.fcircH,x0, y0, r, 3, 0, ccolour, I9341_params())
end sub
 '
sub I9341.drndrect(x as integer, y as integer, w as integer, h as integer, r as integer, rcolour as integer) 'x, y coordinates of top left, width, height, radius of corner
  local integer dp
  dp=I9341draw(I9341.ffr, rcolour, x+r, y, w-2*r, 1,  I9341_params()) 
  dp=I9341draw(I9341.ffr, rcolour, x+r, y+h-1, w-2*r, 1,  I9341_params()) 
  dp=I9341draw(I9341.ffr, rcolour, x, y+r, 1, h-2*r,  I9341_params()) 
  dp=I9341draw(I9341.ffr, rcolour, x+w-1, y+r, 1, h-2*r,  I9341_params()) 
  dp=I9341draw(I9341.dcirch, rcolour, x+r, y+r, r, 1,I9341_params())
  dp=I9341draw(I9341.dcirch,  rcolour, x+w-r-1, y+r, r, 2,I9341_params())
  dp=I9341draw(I9341.dcirch,  rcolour, x+w-r-1, y+h-r-1, r, 4,I9341_params())
  dp=I9341draw(I9341.dcirch,  rcolour, x+r, y+h-r-1, r, 8,I9341_params())
end sub
'
sub I9341.frndrect(x as integer, y as integer, w as integer, h as integer, r as integer, colour as integer) 'x, y coordinates of top left, width, height, radius of corner
  local integer dp
  dp=I9341draw(I9341.ffr, colour, x+r, y, w-2*r, h,  I9341_params()) 
  dp=I9341draw(I9341.fcircH,x+w-r-1, y+r, r, 1, h-2*r-1, colour, I9341_params())
  dp=I9341draw(I9341.fcircH,x+r, y+r, r, 2, h-2*r-1, colour, I9341_params())
end sub
 '
sub I9341.setrot(x%) 'sets screen rotation: 0=I9341_normal, 1=invert, 2=rotate right, 3-rotate left
   local integer i=x% \ 2 '0 for portrait, 1 for landscape
   local integer j=I9341_params(I9341_rot)\2 
   I9341_params(I9341_rot)=(x% and 3)
   if i<>j then 'swap height and width if landscape
     local integer k=I9341_params(I9341_wi)
     I9341_params(I9341_wi)=I9341_params(I9341_ht)
     I9341_params(I9341_ht)=k
   endif  
   on I9341_params(I9341_rot)+1 goto rnor,rinv,rrr,rrl
   rnor:
     I9341.wreg(ILI9341_MEMCONTROL, ILI9341_MADCTL_MX OR ILI9341_MADCTL_BGR,8)
     exit sub
   rinv:
     I9341.wreg(ILI9341_MEMCONTROL, ILI9341_MADCTL_MY OR ILI9341_MADCTL_BGR,8)
     exit sub
   rrr:
     I9341.wreg(ILI9341_MEMCONTROL, ILI9341_MADCTL_MV OR ILI9341_MADCTL_BGR,8)
     exit sub
   rrl:
     I9341.wreg(ILI9341_MEMCONTROL, ILI9341_MADCTL_MY OR ILI9341_MADCTL_MX OR ILI9341_MADCTL_MV OR ILI9341_MADCTL_BGR,8)
end sub
'
'D:\Peter\MPLABXProjects\ILI9341parallel.X\dist\default\production\I9341draw.bas

'
'I9341draw  2015-01-18 14:35:48 CFuncGen Ver 1.0.21 by user=Peter
'
CFunction I9341draw
'writeCommand
	000006B3
	308400ff 3c02bf88 24050001 ac456034 24030002 ac436034 24030004 ac436038 
	24060008 ac466038 ac436034 8c466130 30c60ff0 ac466130 8c466130 00863025 
	00042200 3084f00f 00c42025 ac446130 3c04bf81 8c84f220 ac436038 ac456038 
	03e00008 00000000 

'writeData
3085ff00 308400ff 3c02bf88 24060001 ac466034 24030002 
	ac436038 24030004 ac436038 24070008 ac476038 ac436034 8c476130 30e70ff0 
	ac476130 8c476130 00a73825 7ca51a00 00e52825 ac456130 3c05bf81 8ca7f220 
	ac436038 8ca7f220 ac436034 8c476130 30e70ff0 ac476130 8c476130 00873825 
	00042200 3084f00f 00e42025 ac446130 8ca4f220 ac436038 ac466038 03e00008 
	00000000 

'writeData32
27bdffe8 afbf0014 afb00010 00808021 00042402 0411FFD3 00000000 
	3204ffff 0411FFD0 00000000 8fbf0014 8fb00010 03e00008 27bd0018 

'writebyte
308400ff 
	3c02bf88 24050001 ac456034 24030002 ac436038 24030004 ac436038 24060008 
	ac466038 ac436034 8c466130 30c60ff0 ac466130 8c466130 00863025 00042200 
	3084f00f 00c42025 ac446130 3c04bf81 8c84f220 ac436038 ac456038 03e00008 
	00000000 

'colourrect
27bdffc0 afbf003c afbe0038 afb70034 afb60030 afb5002c afb40028 
	afb30024 afb20020 afb1001c afb00018 00808021 00a09821 00c08821 8fb40050 
	8fa50058 8fa60060 8fa30068 8c620000 8c630008 8e640000 afa40010 0222202b 
	0000b021 10800066 0000b821 2624ffff 00852021 0082a82b 2442ffff 0055200a 
	0283102b 1040005e 0080a821 269effff 03c6f021 03c3102b 2463ffff 0062a80a 
	24020001 00519023 02559021 00541023 005e1021 72429002 2404002a 0411FF68 
	00000000 02202021 0411FF7F 00000000 02a02021 0411FF7C 00000000 2404002b 
	0411FF5F 00000000 02802021 0411FF76 00000000 03c02021 0411FF73 00000000 
	2404002c 0411FF56 00000000 3c02bf88 24030001 ac436034 24030002 ac436038 
	24030004 ac436038 24030008 ac436038 1240002e 00001021 8fa40010 3083ff00 
	308200ff 7c681a00 01034025 00023a00 30e7f00f 00e23825 00002821 3c02bf88 
	24030004 3c04bf81 12000009 00000000 8e660000 30c8ff00 30c600ff 7d071a00 
	00e84025 00063a00 30e7f00f 00e63825 ac436034 8c466130 30c60ff0 ac466130 
	8c466130 01063025 ac466130 8c86f220 ac436038 8c86f220 ac436034 8c466130 
	30c60ff0 ac466130 8c466130 00e63025 ac466130 8c86f220 ac436038 24a50001 
	14b2ffe1 26730004 02401021 24040001 3c03bf88 ac646038 0040b021 0000b821 
	02c01021 02e01821 8fbf003c 8fbe0038 8fb70034 8fb60030 8fb5002c 8fb40028 
	8fb30024 8fb20020 8fb1001c 8fb00018 03e00008 27bd0040 

'localfastfillrect
27bdffc0 afbf003c 
	afa40030 8fa20050 8fa30054 afa20010 afa30014 8fa20058 8fa3005c afa20018 
	afa3001c 8fa20060 8fa30064 afa20020 afa30024 8fa20068 afa20028 00002021 
	27a50030 0411FF5F 00000000 00021fc3 8fbf003c 03e00008 27bd0040 

'localdrawPixel
27bdffe0 
	afbf001c afb20018 afb10014 afb00010 00808021 00c08821 8fb20030 8fa30038 
	8fa40034 8c650000 14e00004 24020001 00c5282b 14a00003 304200ff 00001021 
	304200ff 50400026 00002021 8c630008 14800004 24020001 0243182b 14600003 
	304200ff 00001021 304200ff 5040001c 00002021 2404002a 0411FED1 00000000 
	02202021 0411FEE8 00000000 02202021 0411FEE5 00000000 2404002b 0411FEC8 
	00000000 02402021 0411FEDF 00000000 02402021 0411FEDC 00000000 2404002c 
	0411FEBF 00000000 02002021 0411FED6 00000000 24040001 10000002 00002821 
	00002821 00801021 00a01821 8fbf001c 8fb20018 8fb10014 8fb00010 03e00008 
	27bd0020 

'swap
8c820000 8ca30000 ac830000 03e00008 aca20000 

'drawline
27bdffa8 afbf0054 
	afb70050 afb6004c afb50048 afb40044 afb30040 afb2003c afb10038 afb00034 
	0080a021 00a0a821 8fa40068 8fa20070 8fa30078 8fb30080 afa60020 afa40024 
	afa20028 afa3002c 0083882a 00642823 00831823 0071280a 00c2202a 00461823 
	00c21023 0064100b 0045882a 1220000a 8fa20028 27a40020 27a50024 0411FFD9 
	00000000 27a40028 27a5002c 0411FFD5 00000000 8fa20028 8fa30020 0043102a 
	1040000a 8fa30028 27a40020 27a50028 0411FFCC 00000000 27a40024 27a5002c 
	0411FFC8 00000000 8fa30028 8fa20020 8fa4002c 8fb20024 0244282a 10a00007 
	0062b023 00929023 001687c2 02168021 00108043 10000006 24170001 02449023 
	001687c2 02168021 00108043 2417ffff 0062182a 14600028 8fbf0054 1220000e 
	8fa30024 8fa70024 afa20010 000217c3 afa20014 afb30018 02802021 02a02821 
	00e03021 00073fc3 0411FF64 00000000 1000000c 02128023 afa30010 00031fc3 
	afa30014 afb30018 02802021 02a02821 00403021 00023fc3 0411FF58 00000000 
	02128023 06010006 8fa20020 8fa20024 00571021 afa20024 02168021 8fa20020 
	24420001 afa20020 8fa30028 0062182a 1060ffda 8fbf0054 8fb70050 8fb6004c 
	8fb50048 8fb40044 8fb30040 8fb2003c 8fb10038 8fb00034 03e00008 27bd0058 

'drawchar
	27bdfea0 afbf015c afbe0158 afb70154 afb60150 afb5014c afb40148 afb30144 
	afb20140 afb1013c afb00138 00c0b821 8fb00178 afa400f8 afa500fc 8fa4017c 
	14800063 00e0f021 0200b021 8fa50174 afa50108 afa00114 afa00118 27a600f7 
	afa60100 00108fc3 000717c3 afa2011c 00171fc3 afa30124 afb7010c afa70110 
	02009821 1000003d 0220b821 92020000 02821024 10400016 00000000 56750004 
	afbe0010 8fa4010c 10000024 ae440000 8fa50104 afa50014 afb30018 afb7001c 
	afb30020 afb70024 8fa60180 afa60028 8fa4010c 8fa50124 02203021 00113fc3 
	0411FEED 00000000 10000015 2610ffff 56750004 afbe0010 8fa20110 1000000f 
	ae420000 8fa30104 afa30014 afb30018 afb7001c afb30020 afb70024 8fa40180 
	afa40028 8fa40110 8fa5011c 02203021 00113fc3 0411FED8 00000000 2610ffff 
	02368821 8fa50100 1605ffd0 26520004 8fa60118 24c60006 afa60118 8fa20114 
	24420001 afa20114 8fa30108 00761821 24020030 10c2000f afa30108 24140001 
	8fa40114 0094a004 8fbe0108 001e2fc3 afa50104 27b000fd 8fb10170 8fa60118 
	00069080 27a20030 00529021 1000ffb7 24150001 8fb7010c 8fbe0110 02608021 
	00131040 001318c0 1000007e 00621023 24040001 8fa5017c 14a40079 0200b021 
	8fa60174 24c60001 afa60134 001010c0 00c21023 afa2010c 24020007 afa20114 
	afa00118 8fa30170 24630001 afa30124 00701823 00101080 00501021 00621023 
	afa2012c 27a400fe afa40100 00108fc3 00072fc3 afa5011c afa70110 02e0f021 
	02009821 1000003e 0220b821 92020000 02821024 10400016 00000000 16750003 
	8fa60104 10000026 ae5e0000 afa60010 8fa20108 afa20014 afb30018 afb7001c 
	afb30020 afb70024 8fa30180 afa30028 03c02021 8fa50120 02203021 00113fc3 
	0411FE7D 00000000 10000016 26100001 16750004 8fa50104 8fa40110 10000010 
	ae440000 afa50010 8fa60108 afa60014 afb30018 afb7001c afb30020 afb70024 
	8fa20180 afa20028 8fa40110 8fa5011c 02203021 00113fc3 0411FE67 00000000 
	26100001 02368821 8fa30100 1603ffcf 26520004 8fa40118 24840006 afa40118 
	8fa50114 24a5ffff afa50114 8fa6010c 00d63021 24020030 10820014 afa6010c 
	24140001 8fa20114 0054a004 8fa3010c afa30104 000327c3 afa40108 27b000f8 
	8fa50124 afa50130 8fb1012c 8fa60118 00069080 27a20030 00529021 24150001 
	001e1fc3 1000ffb1 afa30120 03c0b821 8fbe0110 02608021 001318c0 8fa40134 
	00832023 afa40174 00131040 00621023 8fa50130 00a22823 10000075 afa50170 
	afa00118 24040002 8fa6017c 14c40072 24040003 0200a821 8fa20174 afa20114 
	27b400fd 27a300f7 afa30100 8fa40118 afa4011c 8fa50170 24a50001 afa50128 
	001010c0 00a21023 afa20134 00108fc3 001e37c3 afa60120 001717c3 afa20124 
	afb7010c afbe0110 02009821 1000003e 0220f021 92820000 02021007 30420001 
	10400017 00000000 16760004 8fa40104 8fa3010c 10000026 ae430000 afa40010 
	8fa50108 afa50014 afb30018 afbe001c afb30020 afbe0024 8fa60180 afa60028 
	8fa4010c 8fa50124 02203021 00113fc3 0411FE01 00000000 10000016 2610ffff 
	16760004 8fa30104 8fa20110 10000010 ae420000 afa30010 8fa40108 afa40014 
	afb30018 afbe001c afb30020 afbe0024 8fa50180 afa50028 8fa40110 8fa50120 
	02203021 00113fc3 0411FDEB 00000000 2610ffff 02358821 1617ffce 26520004 
	8fa6011c 24c60008 afa6011c 8fa20114 00551021 afa20114 2694ffff 8fa30100 
	52830010 02608021 8fa40114 afa40104 00042fc3 afa50108 8fa60128 afa60130 
	8fb10134 8fa2011c 00029080 27a30030 00729021 24100007 24160001 1000ffb5 
	2417ffff 8fa40118 24840030 afa40118 001318c0 8fa50130 00a32823 afa50170 
	00601021 00132040 1000006a 00641823 24040003 8fa6017c 14c40067 24040001 
	0200a821 00101840 001010c0 00621023 24420001 8fa30174 00621821 afa30174 
	afa30110 27b400f8 27a400fe afa40100 8fa50118 afa50114 00108fc3 001e37c3 
	afa6011c 001717c3 afa20124 afb70108 afbe010c 02009821 1000003d 0220b821 
	92820000 02021007 30420001 50400017 24020001 24030001 56630004 afbe0010 
	8fa40108 10000024 ae440000 8fa50104 afa50014 afb30018 afb7001c afb30020 
	afb70024 8fa60180 afa60028 8fa40108 8fa50124 02203021 00113fc3 0411FD8E 
	00000000 10000015 26100001 56620004 afbe0010 8fa3010c 1000000f ae430000 
	8fa40104 afa40014 afb30018 afb7001c afb30020 afb70024 8fa50180 afa50028 
	8fa4010c 8fa5011c 02203021 00113fc3 0411FD79 00000000 26100001 02358821 
	1616ffcf 26520004 8fa60114 24c60008 afa60114 8fa20110 00551021 afa20110 
	26940001 8fa30100 5283000c 02608021 8fbe0110 001e27c3 afa40104 8fb10170 
	8fa50114 00059080 27a60030 00d29021 00008021 1000ffba 24160008 8fa20118 
	24420030 afa20118 001310c0 00131840 00431823 24040001 56040015 8fa20118 
	8fa40174 afa40010 000427c3 afa40014 afa20018 000217c3 afa2001c afa30020 
	00031fc3 afa30024 8fa60180 afa60028 24040001 27a50030 8fa60170 00063fc3 
	0411FCB8 00000000 afa20118 8fa20118 00021fc3 8fbf015c 8fbe0158 8fb70154 
	8fb60150 8fb5014c 8fb40148 8fb30144 8fb20140 8fb1013c 8fb00138 03e00008 
	27bd0160 

'nextchar
14e00008 24020001 00061040 000618c0 00621023 8c830000 00621021 
	10000012 ac820000 14e20007 00061040 000630c0 00c23023 8c820000 00463023 
	03e00008 ac860000 24020002 14e20007 00061040 000630c0 00c23023 8ca20000 
	00463021 03e00008 aca60000 24020003 14e20006 00061040 000630c0 00c23023 
	8ca20000 00463023 aca60000 03e00008 00000000 

'pstring
27bdffa0 afbf005c afbe0058 
	afb70054 afb60050 afb5004c afb40048 afb30044 afb20040 afb1003c afb00038 
	8fa80070 8fb00078 8fa20080 afa20034 8fa20088 8fa70090 8fb50098 8fb2009c 
	afa60028 afa8002c 0200a021 8fb30034 0040f021 afa40030 92430000 1060002c 
	00e0b821 1860003b 24100001 02501021 90420000 2443ffe0 306300ff 2c630060 
	50600008 00002021 2442ffe0 000210c0 8fa30030 00431021 8c440000 10000002 
	8c450004 00002821 8fa20028 afa20010 8fa2002c afa20014 afb40018 afb3001c 
	afb50020 03c03021 02e03821 0411FDB4 00000000 00408821 0060b021 27a40028 
	27a5002c 02803021 02603821 0411FF9D 00000000 26100001 92420000 0050102a 
	5040ffdb 02501021 10000013 8fa20028 afa60010 afa80014 afb00018 8fa30034 
	afa3001c afb50020 00403021 0411FD9C 00000000 00408821 0060b021 27a40028 
	27a5002c 02003021 8fa70034 0411FF85 00000000 8fa20028 aea20020 000217c3 
	aea20024 8fa2002c aea20028 000217c3 aea2002c 02201021 02c01821 8fbf005c 
	8fbe0058 8fb70054 8fb60050 8fb5004c 8fb40048 8fb30044 8fb20040 8fb1003c 
	8fb00038 03e00008 27bd0060 

'dcirch
27bdffa0 afbf005c afbe0058 afb70054 afb60050 
	afb5004c afb40048 afb30044 afb20040 afb1003c afb00038 afa40060 afa50064 
	00c0b021 8fb50070 8fb00078 8fa20080 8fb70088 afa60024 afb50028 afa20020 
	30420010 1040002a 02008821 000697c3 02151021 afa20010 000217c3 afa20014 
	afb70018 02403821 0411FC9C 00000000 02b01023 afa20010 000217c3 afa20014 
	afb70018 8fa40060 8fa50064 02c03021 02403821 0411FC91 00000000 001597c3 
	02163821 afb50010 afb20014 afb70018 8fa40060 8fa50064 00e03021 00073fc3 
	0411FC86 00000000 02d03823 afb50010 afb20014 afb70018 8fa40060 8fa50064 
	00e03021 00073fc3 0411FC7C 00000000 1a20008f 24110001 02308823 0010f023 
	001ef040 26b3ffff 26d4ffff 26b50001 26d60001 00009021 8fa20020 30420004 
	afa2002c 8fa30020 30630002 afa30030 8fa20020 30420008 afa20034 8fa30020 
	30630001 afa30020 06200004 8fa2002c 2610ffff 27de0002 023e8821 10400019 
	26520001 8fa30028 02031021 afa20010 000217c3 afa20014 afb70018 8fa40060 
	8fa50064 02c03021 00163fc3 0411FC53 00000000 8fa20024 02023821 afb50010 
	001517c3 afa20014 afb70018 8fa40060 8fa50064 00e03021 00073fc3 0411FC47 
	00000000 8fa30030 1060001a 8fa30034 8fa30028 00701023 afa20010 000217c3 
	afa20014 afb70018 8fa40060 8fa50064 02c03021 00163fc3 0411FC38 00000000 
	8fa20024 02023821 afb30010 001317c3 afa20014 afb70018 8fa40060 8fa50064 
	00e03021 00073fc3 0411FC2C 00000000 8fa30034 1060001a 8fa20020 8fa20024 
	00503823 afb50010 001517c3 afa20014 afb70018 8fa40060 8fa50064 00e03021 
	00073fc3 0411FC1D 00000000 8fa30028 02031021 afa20010 000217c3 afa20014 
	afb70018 8fa40060 8fa50064 02803021 00143fc3 0411FC11 00000000 8fa20020 
	5040001a 2673ffff 8fa30024 00703823 afb30010 001317c3 afa20014 afb70018 
	8fa40060 8fa50064 00e03021 00073fc3 0411FC02 00000000 8fa30028 00701023 
	afa20010 000217c3 afa20014 afb70018 8fa40060 8fa50064 02803021 00143fc3 
	0411FBF6 00000000 2673ffff 2694ffff 26b50001 0250102a 10400005 26d60001 
	00121040 24420001 1000ff87 02228821 8fbf005c 8fbe0058 8fb70054 8fb60050 
	8fb5004c 8fb40048 8fb30044 8fb20040 8fb1003c 8fb00038 03e00008 27bd0060 

'fcirch
	27bdff90 afbf006c afbe0068 afb70064 afb60060 afb5005c afb40058 afb30054 
	afb20050 afb1004c afb00048 8fb10080 8fb40090 8fbe00a0 afa40038 afa6003c 
	8fa20088 1a200076 02801821 24100001 02118023 0011b823 0017b840 2495ffff 
	24d3ffff 26940003 24960001 00009021 30440001 afa40030 24630001 afa30040 
	30420002 afa20034 06000004 8fa20030 2631ffff 26f70002 02178021 1040002a 
	26520001 8fa3003c 00711023 afa20010 000217c3 afa20014 24020001 00001821 
	afa20018 afa3001c 00111040 8fa30040 00621021 afa20020 000217c3 afa20024 
	afbe0028 8fa40098 8fa5009c 02c03021 00163fc3 0411FB88 00000000 8fa40038 
	02243821 afb30010 001317c3 afa20014 24020001 00001821 afa20018 afa3001c 
	afb40020 001417c3 afa20024 afbe0028 8fa40098 8fa5009c 00e03021 00073fc3 
	0411FB75 00000000 8fa30034 5060002b 26b5ffff 8fa4003c 00911023 afa20010 
	000217c3 afa20014 24020001 00001821 afa20018 afa3001c 00111040 8fa30040 
	00621021 afa20020 000217c3 afa20024 afbe0028 8fa40098 8fa5009c 02a03021 
	00153fc3 0411FB5C 00000000 8fa40038 00913823 afb30010 001317c3 afa20014 
	24020001 00001821 afa20018 afa3001c afb40020 001417c3 afa20024 afbe0028 
	8fa40098 8fa5009c 00e03021 00073fc3 0411FB49 00000000 26b5ffff 2673ffff 
	26940002 0251102a 10400005 26d60001 00121040 24420001 1000ff9b 02028021 
	8fbf006c 8fbe0068 8fb70064 8fb60060 8fb5005c 8fb40058 8fb30054 8fb20050 
	8fb1004c 8fb00048 03e00008 27bd0070 

'ftri
27bdff88 afbf0074 afb70070 afb6006c 
	afb50068 afb40064 afb30060 afb2005c afb10058 afb00054 8fa20090 8fb400a8 
	8fb500ac 8fb100b0 afa40038 afa6003c 8fa30088 afa30040 afa20044 8fa30098 
	afa30048 8fa300a0 0046102a 10400009 afa3004c 27a4003c 27a50044 0411FB71 
	00000000 27a40038 27a50040 0411FB6D 00000000 8fa2004c 8fa30044 0043102a 
	1040000a 8fa20044 27a4004c 27a50044 0411FB64 00000000 27a40048 27a50040 
	0411FB60 00000000 8fa20044 8fa3003c 0043102a 1040000a 8fb0003c 27a4003c 
	27a50044 0411FB57 00000000 27a40038 27a50040 0411FB53 00000000 8fb0003c 
	8fa2004c 1602002e 8fb20044 8fa20038 afa20030 afa20034 8fa30040 0062202a 
	10800003 0043102a 10000003 afa30030 54400001 afa30034 8fa20048 8fa30030 
	0043182a 10600003 8fa30034 10000004 afa20030 0062182a 54600001 afa20034 
	8fa70030 8fa2003c afa20010 000217c3 afa20014 24020001 00001821 afa20018 
	afa3001c 8fa20034 24420001 00471023 afa20020 000217c3 afa20024 afb10028 
	02802021 02a02821 00e03021 00073fc3 0411FAC9 00000000 1000007a 8fbf0074 

'.LBB2
	00521026 0002102b 02429023 0250102a 14400039 8fa2004c 24160001 0000b821 
	8fa20038 8fa3003c 02032823 8fa60040 00c23023 70a63002 8fa40044 00832023 
	00c4001a 008001f4 00002012 00822021 afa40030 8fa60048 00c23023 70a62802 
	8fa6004c 00c31823 00a3001a 006001f4 00001812 00621021 afa20034 0044102a 
	10400006 8fa70030 27a40030 27a50034 0411FAFC 00000000 8fa70030 afb00010 
	001017c3 afa20014 8fa20034 24420001 00471023 afa20018 000217c3 afa2001c 
	afb60020 afb70024 afb10028 02802021 02a02821 00e03021 00073fc3 0411FA8E 
	00000000 26100001 0250102a 1040ffcd 8fa20038 8fa2004c 0050182a 14600038 
	24120001 00009821 8fa60040 8fa40038 8fa50048 8fa80044 02083823 00a61823 
	70e33802 00484023 00e8001a 010001f4 00001812 00661821 afa30030 8fa7003c 
	02073023 00a42823 70c53002 00471023 00c2001a 004001f4 00001012 00442021 
	afa40034 0083202a 10800006 8fa70030 27a40030 27a50034 0411FAC2 00000000 
	8fa70030 afb00010 001017c3 afa20014 8fa20034 24420001 00471023 afa20018 
	000217c3 afa2001c afb20020 afb30024 afb10028 02802021 02a02821 00e03021 
	00073fc3 0411FA54 00000000 26100001 8fa2004c 0050182a 1060ffcc 8fa60040 

'.LBE2
	8fbf0074 8fb70070 8fb6006c 8fb50068 8fb40064 8fb30060 8fb2005c 8fb10058 
	8fb00054 03e00008 27bd0078 

'main
27bdffb8 afbf0044 afb00040 00808021 00e01021 
	8faa0058 8fa9005c 8fa80060 8fac0064 8c830000 8c840004 00643825 14e00010 
	8fab0068 8ca50000 8cc70000 8c420000 afa20010 000217c3 afa20014 afaa0018 
	00a02021 00052fc3 00e03021 00073fc3 0411FA42 00000000 100000da 8fbf0044 
	24070001 14670018 24070002 14800016 00000000 8ca40000 8ca50004 8cc70004 
	8cc60000 8c430004 8c420000 afa20010 afa30014 8d420000 8d430004 afa20018 
	afa3001c 8d220000 8d230004 afa20020 afa30024 afa80028 0411FA0F 00000000 
	100000c0 8fbf0044 14670021 24070003 1480001f 00000000 8ca40000 8ca50004 
	8cc70004 8cc60000 8c430004 8c420000 afa20010 afa30014 8d420000 8d430004 
	afa20018 afa3001c 8d220000 8d230004 afa20020 afa30024 8d020000 8d030004 
	afa20028 afa3002c 8d820000 8d830004 afa20030 afa30034 afab0038 0411FEBC 
	00000000 8e020000 1000009d 8e030004 14670019 24070004 14800017 00000000 
	8ca40000 8ca50004 8cc70004 8cc60000 8c420000 afa20010 000217c3 afa20014 
	8d420000 afa20018 000217c3 afa2001c 8d220000 afa20020 000217c3 afa20024 
	afa80028 0411FA34 00000000 8e020000 10000083 8e030004 14670009 24070005 
	14800007 00000000 8ca40000 0411F8D4 00000000 8e020000 10000079 8e030004 
	14670009 24070007 14800007 00000000 8ca40000 0411F8E4 00000000 8e020000 
	1000006f 8e030004 14670022 24070008 14800020 00000000 8ca40000 8ca50004 
	8cc70004 8cc60000 8c430004 8c420000 afa20010 afa30014 8d420000 8d430004 
	afa20018 afa3001c 8d220000 8d230004 afa20020 afa30024 8d020000 8d030004 
	afa20028 afa3002c 8d820000 8d830004 afa20030 afa30034 afab0038 8fa2006c 
	afa2003c 0411FC8B 00000000 1000004d 8fbf0044 1467001d 24070009 1480001b 
	00000000 8ca40000 8ca50004 8cc70004 8cc60000 8c430004 8c420000 afa20010 
	afa30014 8d420000 8d430004 afa20018 afa3001c 8d220000 8d230004 afa20020 
	afa30024 8d020000 8d030004 afa20028 afa3002c afac0030 0411FDB9 00000000 
	8e020000 1000002e 8e030004 54670019 2402000a 54800017 2402000a 8ca40000 
	8ca50004 8cc70004 8cc60000 8c430004 8c420000 afa20010 afa30014 8d420000 
	8d430004 afa20018 afa3001c 8d220000 8d230004 afa20020 afa30024 afa80028 
	0411FCC2 00000000 8e020000 10000014 8e030004 14620009 2402000b 14800007 
	00000000 8ca40000 0411F8B4 00000000 8e020000 1000000a 8e030004 14620009 
	8fbf0044 54800008 8fb00040 8ca40000 0411F89C 00000000 8e020000 8e030004 
	8fbf0044 8fb00040 03e00008 27bd0048 
End CFunction
'
CFunction font
	00000000
	00000000 00000000 5f000000 00000000 00070000 00000007 147f1400 0000147f 
	7f2a1200 0000242a 08646200 00002313 56205000 00003649 07030000 00000008 
	22410000 0000001c 221c0000 00000041 7f1c2a00 00002a1c 3e080800 00000808 
	70300000 00000080 08080800 00000808 60600000 00000000 08040200 00002010 
	49453e00 00003e51 7f400000 00000042 49494600 00007249 494d3300 00002141 
	127f1000 00001814 45453900 00002745 49493100 00003c4a 11090700 00004121 
	49493600 00003649 49291e00 00004649 14000000 00000000 34000000 00000040 
	14224100 00000008 14141400 00001414 22140800 00000041 59090600 00000201 
	5d594e00 00003e41 11127c00 00007c12 49493600 00007f49 41412200 00003e41 
	41413e00 00007f41 49494100 00007f49 09090100 00007f09 41517300 00003e41 
	08087f00 00007f08 7f410000 00000041 413f0100 00002040 14224100 00007f08 
	40404000 00007f40 1c027f00 00007f02 08107f00 00007f04 41413e00 00003e41 
	09090600 00007f09 51215e00 00003e41 19294600 00007f09 49493200 00002649 
	7f010300 00000301 40403f00 00003f40 40201f00 00001f20 38403f00 00003f40 
	08146300 00006314 78040300 00000304 494d4300 00006159 41414100 0000007f 
	08102000 00000204 41417f00 00000041 01020400 00000402 40404000 00004040 
	07080000 00000003 54784000 00002054 44443800 00007f28 44442800 00003844 
	44287f00 00003844 54541800 00003854 7e090200 00000008 a49c7800 000018a4 
	04047800 00007f08 7d400000 00000044 403d0000 00002040 28440000 00007f10 
	7f400000 00000041 78047800 00007c04 04047800 00007c08 44443800 00003844 
	24241800 0000fc18 2418fc00 00001824 04040800 00007c08 54542400 00004854 
	3f442400 00000404 40207c00 00003c40 40201c00 00001c20 30403c00 00003c40 
	10284400 00004428 90907c00 00004c90 544c4400 00004464 36410000 00000008 
	77000000 00000000 36080000 00000041 02040200 00000201 23263c00 00003c26 
End CFunction
'
sub I9341_initialise
  I9341.initdisplay
  print "Controller type :", hex$(I9341.rreg(&HD3), 4)
end sub
'
sub I9341_test
  local integer i, xfs, yfs, x0, y0, x1, y1, wi, ht, sz
  local float tn
  I9341.setrot(0)
  wi= I9341_params(0)
  ht= I9341_params(1)
  I9341.fillscreen(black)
  I9341.drect(0, 0, wi, ht, red)
  I9341.pbitmap(114, 10, -1, 2, 0, magenta, black)
  I9341.pstring(40, 40, "Welcome to the", 2, 0, green, black)
  I9341.pstring(5, 70, "Micromite MK2", 3, 0, red, black)
  I9341.pstring(60, 120, "in colour", 2, 0, yellow, black)
  I9341.pstring(60, 170,  "ILI9341 controller", 1, 0, cyan, black)
  pause 2000
' demo fast line draw
  I9341.setrot(I9341_normal)
  I9341.fillscreen(black)
  x0=0:y0=0:y1=ht-1
  for i=0 to 44 step 2
    tn=tan(rad(i))
    x1=wi*tn
    I9341.dline(x0, y0, x1, y1, red)
  next i
  x1=wi-1
  for i=0 to 44 step 2
    tn=tan(rad(i))
    y1=ht*tn
    I9341.dline(x0, y0, x1, y1, red)
  next i
  I9341.drect(0, 00, wi, ht, blue)
  pause 2000
  I9341.fillscreen(black)
'demo fast text write
  I9341.setrot(I9341_rt_right)
  for i=0 to wi-8 step 8
    I9341.pstring(0, i, "Hello world:Bye world:Hello world:Bye world:Hello world:Bye world", 1, I9341_normal, green, black)
  next i
  I9341.setrot(I9341_normal)
  pause 2000
  I9341.fillscreen(black)
  for i=ht-1 to 15 step -16
    I9341.pstring(wi-1, i, "Micromite MK2:Micromite MK2", 2, I9341_inverse, red, black)
  next i
  pause 2000
  I9341.fillscreen(black)
  for i=24 to wi step 24
    I9341.pstring(i, 0, "Rotate right:Rotate right", 3, I9341_rt_right, yellow, black)
  next i
  pause 2000
  I9341.fillscreen(black)
  for i=wi-32 to 0 step -32
    I9341.pstring(i, ht-1, "Rotate Left:Rotate Left", 4, I9341_rt_left, blue, black)
  next i
  pause 2000
  I9341.fillscreen(black)
  ' test drawing rectangles
  for i=0 to 3
     I9341.setrot(i)
     I9341.frect(5, 5, 30, 45, blue)
     I9341.drect(2, 2, 36, 51, red)
  next i
  pause 2000
' test drawing rounded rectangles
  I9341.fillscreen(black)
  for i=0 to 3
     I9341.setrot(i)
     I9341.frndrect(5, 5, 30, 45, 10, blue)
     I9341.drndrect(2, 2, 36, 51, 12, red)
  next i
  pause 2000
  I9341.fillscreen(black)
' test drawing circles
  for i=0 to 3
     I9341.setrot(i)
     I9341.fcirc(40, 40, 37, blue)
     I9341.dcirc(40, 40, 39, red)
  next i
  pause 2000
' test drawing triangles and line drawing
  I9341.fillscreen(black)
  for i=0 to 3
     I9341.setrot(i)
     I9341.ftri(4, 4, 40, 6, 22, 24, blue)
     I9341.dtri(1, 2, 44, 4, 22, 27, red)
  next i
  pause 2000
' test character output and string output at all orientations
  for sz=1 to 3
  I9341.fillscreen(black)
  I9341.setrot(I9341_normal)
  I9341.pstring(wi/2, ht/2, "N", 3, I9341_normal, white, black)
  I9341.pstring(0, 0, "I9341_normal", sz, I9341_normal, red, black)
  I9341.pstring(wi-1, ht-1, "Inverted", sz, I9341_inverse, blue, black)
  I9341.pstring(wi-1, 0, "Rotated right", sz, I9341_rt_right, green, black)
  I9341.pstring(0, ht-1, "Rotated left", sz, I9341_rt_left, yellow, black)
  pause 1000
  I9341.fillscreen(black)
  I9341.setrot(I9341_inverse)
  I9341.pstring(wi/2, ht/2, "I", 3, I9341_inverse, white, black)
  I9341.pstring(0, 0, "I9341_normal", sz, I9341_normal, red, black)
  I9341.pstring(wi-1, ht-1, "Inverted", sz, I9341_inverse, blue, black)
  I9341.pstring(wi-1, 0, "Rotated right", sz, I9341_rt_right, green, black)
  I9341.pstring(0, ht-1, "Rotated left", sz, I9341_rt_left, yellow, black)
  pause 1000
  I9341.fillscreen(black)
  I9341.setrot(I9341_rt_right)
  I9341.pstring(ht/2, wi/2, "R", 3, I9341_rt_left, white, black)
  I9341.pstring(0, 0, "I9341_normal", sz, I9341_normal, red, black)
  I9341.pstring(ht-1, wi-1, "Inverted", sz, I9341_inverse, blue, black)
  I9341.pstring(ht-1, 0, "Rotated right", sz, I9341_rt_right, green, black)
  I9341.pstring(0, wi-1, "Rotated left", sz, I9341_rt_left, yellow, black)
  pause 1000
  I9341.fillscreen(black)
  I9341.setrot(I9341_rt_left)
  I9341.pstring(ht/2, wi/2, "L", 3, I9341_rt_right, white, black)
  I9341.pstring(0, 0, "I9341_normal", sz, I9341_normal, red, black)
  I9341.pstring(ht-1, wi-1, "Inverted", sz, I9341_inverse, blue, black)
  I9341.pstring(ht-1, 0, "Rotated right", sz, I9341_rt_right, green, black)
  I9341.pstring(0, wi-1, "Rotated left", sz, I9341_rt_left, yellow, black)
  pause 1000
  next sz
end SUB
